# -*- coding: utf-8 -*-

# Copyright (C) 2013 Avencall
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>

import os
import shutil
from xivo_callgen.config import ScenarioConfig
from xivo_callgen.scenario import Scenario, ScenarioRunner

_CONF_DIR = '/etc/xivo-callgen'
_TMP_DIR = '/tmp'
_TMP_SC_DIR = os.path.join(_TMP_DIR, 'scenarios')


class XivoCallGenStep(object):

    _ls_scenario = []

    @classmethod
    def build_calling_line(cls, args_dict, data_dict=None, user='', passwd=''):
        if data_dict is None:
            data_dict = {}
        if 'calling_line_user' not in data_dict:
            calling_line_user = user
            calling_line_passwd = passwd
        else:
            calling_line_user = data_dict['calling_line_user']
            calling_line_passwd = data_dict['calling_line_passwd']

        args_dict['calling_line'] = {
            'username': calling_line_user,
            'password': calling_line_passwd
        }

    @classmethod
    def build_args_dict(cls, data_dict):
        args_dict = {}
        if 'called_exten' in data_dict and data_dict['called_exten'] is not None:
            args_dict.update({'called_extens': [data_dict['called_exten']]})
            del(data_dict['called_exten'])

        if 'call_duration' in data_dict:
            args_dict['pause'] = {'distribution': 'fixed', 'value': data_dict['call_duration']}
            del(data_dict['call_duration'])

        if 'ring_time' in data_dict:
            args_dict['ring_time'] = {'distribution': 'fixed', 'value': data_dict['ring_time']}
            del(data_dict['ring_time'])

        args_dict.update(data_dict)
        return args_dict

    @classmethod
    def _get_idx_for_scenario(cls, name_scenario):
        dirs = os.listdir(_TMP_SC_DIR)
        idx_exists = []
        for directory in dirs:
            if directory.startswith(name_scenario):
                idx = directory.split('%s-' % name_scenario)
                if idx[1]:
                    idx_exists.append(int(idx[1]))
        return (max(idx_exists) + 1) if idx_exists else 1

    @classmethod
    def _gener_scenario(cls, name_scenario):
        if not os.access(_TMP_SC_DIR, os.W_OK):
            os.mkdir(_TMP_SC_DIR)
        idx = cls._get_idx_for_scenario(name_scenario)
        scenario_path = os.path.join(_TMP_SC_DIR, '%s-%s' % (name_scenario, idx))
        scenario_path_tpl = os.path.join(_CONF_DIR, 'scenarios-tpl', name_scenario)
        shutil.copytree(scenario_path_tpl, scenario_path)
        cls._ls_scenario.append(scenario_path)
        return scenario_path

    @classmethod
    def clean_scenario(cls):
        for scenario in cls._ls_scenario:
            shutil.rmtree(scenario)

    @classmethod
    def launch_scenario(cls, name_scenario, args_dict):
        scenario = Scenario(cls._gener_scenario(name_scenario))
        scenario_config = ScenarioConfig.new_from_dict(args_dict)
        ScenarioRunner().start_scenario(scenario, scenario_config)
