# -*- coding: utf-8 -*-

# Copyright (C) 2013 Avencall
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>

import unittest
from xivo_callgen.config import ScenarioConfig


class TestScenarioConfig(unittest.TestCase):

    def _new_context(self, context=None):
        base_context = {'sipp_std_options': ''}
        if base_context is not None:
            base_context.update(context)
        return base_context

    def test_sipp_std_options_is_built(self):
        config_dict = {'sipp_rate_period_in_ms': 1000,
                       'sipp_call_rate': 1.0,
                       'sipp_local_ip': 'local_ip',
                       'sipp_max_simult_calls': 3,
                       'sipp_nb_of_calls_before_exit': 4,
                       'sipp_remote_host': 'skarodev',
                       'sipp_enable_trace_calldebug': True,
                       'sipp_enable_trace_err': True,
                       'sipp_enable_trace_shortmsg': True,
                       'sipp_enable_trace_stat': True,
                       'sipp_enable_background_mode': True}

        config = ScenarioConfig(config_dict)

        sipp_std_options = config.get_context_for_scenario('s1')['sipp_std_options']
        self.assertEqual('-i local_ip -r 1.0 -rp 1000 -l 3 -m 4 -trace_calldebug -trace_err -trace_shortmsg -trace_stat -bg',
                         sipp_std_options)

    def test_sipp_std_option_when_sipp_enable_traces_are_false(self):
        config_dict = {
            'sipp_enable_trace_calldebug': False,
            'sipp_enable_trace_err': False,
            'sipp_enable_trace_shortmsg': False,
            'sipp_enable_trace_stat': False
        }

        config = ScenarioConfig(config_dict)

        sipp_std_options = config.get_context_for_scenario('s1')['sipp_std_options']
        self.assertEqual('', sipp_std_options)
